@@ -77,6 +77,11 @@ pub fn async_middleware(items: TokenStream) -> TokenStream {
     gen.into()
 }
 
+#[proc_macro_attribute]
+pub fn middleware(attr: TokenStream, item: TokenStream) -> TokenStream {
+    middleware_fn(attr, item)
+}
+
 #[proc_macro_attribute]
 pub fn middleware_fn(attr: TokenStream, item: TokenStream) -> TokenStream {
     if let syn::Item::Fn(mut function_item) = syn::parse(item.clone()).unwrap() {
